@@ -223,22 +223,22 @@ class CloudFrontToApiGateway(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontWebDistribution")
     def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
         return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontFunction")
     def cloud_front_function(self) -> typing.Optional[aws_cdk.aws_cloudfront.Function]:
         return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.Function], jsii.get(self, "cloudFrontFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
     def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
@@ -272,7 +272,7 @@ class CloudFrontToApiGatewayProps:
         :summary: The properties for the CloudFrontToApiGateway Construct
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = BucketProps(**cloud_front_logging_bucket_props)
         if __debug__:
             type_hints = typing.get_type_hints(CloudFrontToApiGatewayProps.__init__)
             check_type(argname="argument existing_api_gateway_obj", value=existing_api_gateway_obj, expected_type=type_hints["existing_api_gateway_obj"])
